@@ -5,19 +5,13 @@ use strict;
 use warnings;
 use Exporter qw/import/;
 
-our $VERSION   = "0.11_01";
-our @EXPORT    = qw/InJoyoKanji InJouyouKanji InJinmeiyoKanji InJinmeiyouKanji/;
-our @EXPORT_OK = qw/InJoyoKanji20101130 InJouyouKanji20101130 InJinmeiyoKanji20101130 InJinmeiyouKanji20101130/;
+our $VERSION   = "0.01";
+our @EXPORT    = qw/InJoyoKanji InJouyouKanji/;
+our @EXPORT_OK = qw//;
 
-*InJoyoKanji           = \&InJoyoKanji20101130;
-*InJouyouKanji         = \&InJoyoKanji;
-*InJouyouKanji20101130 = \&InJoyoKanji20101130;
+*InJouyouKanji = \&InJoyoKanji;
 
-*InJinmeiyoKanji          = \&InJinmeiyoKanji20101130;
-*InJinmeiyouKanji         = \&InJinmeiyoKanji;
-*InJinmeiyouKanji20101130 = \&InJinmeiyoKanji20101130;
-
-sub InJoyoKanji20101130
+sub InJoyoKanji
 {
     return <<"END";
 4E00
@@ -2000,844 +1994,6 @@ sub InJoyoKanji20101130
 END
 }
 
-sub InJinmeiyoKanji20101130
-{
-    return <<"END";
-4E11
-4E1E
-4E43
-4E4B
-4E4E
-4E5F
-4E91
-4E98
-4E99
-4E9B
-4EA5
-4EA6
-4EA8
-4EAE
-4ED4
-4F0A
-4F0D
-4F36
-4F3D
-4F43
-4F51
-4F83
-4F91
-4FC4
-4FD0
-4FE0
-4FE3
-4FF1
-5016
-5026
-502D
-5072
-50AD
-5132
-5141
-514E
-515C
-5176
-51B4
-51CC
-51DB
-51DC
-51E7
-51EA
-51F0
-51F1
-51FD
-5289
-52AB
-52C1
-52FA
-52FF
-5301
-5321
-535C
-536F
-537F
-53A8
-53A9
-53C9
-53E1
-53E2
-53EA
-53F6
-541E
-543B
-543E
-54C9
-54E8
-54E9
-5544
-558B
-55A7
-55AC
-55B0
-5609
-5617
-5629
-5642
-564C
-5703
-572D
-5750
-5766
-57F4
-582F
-5830
-5835
-583A
-5859
-58D5
-58EC
-5937
-5944
-594E
-5957
-59E5
-59EA
-5A03
-5A29
-5B09
-5B5C
-5B5F
-5B8B
-5B8F
-5B95
-5BA5
-5BC5
-5BD3
-5BF5
-5C16
-5C24
-5C2D
-5C51
-5CE8
-5CFB
-5D1A
-5D69
-5D6F
-5DBA
-5DCC
-5DD6
-5DF2\t5DF4
-5DF7
-5DFD
-5E16
-5E4C
-5E61
-5E84
-5E87
-5E9A
-5EB5
-5EDF
-5EFB
-5EFF
-5F18
-5F1B
-5F57
-5F66
-5F6A
-5F6C
-5FA0
-5FBD
-5FFD
-601C
-6055
-6062
-6070
-6089
-608C
-60C7
-60DA
-60DF
-60E3
-60F9
-60FA
-6167
-6190
-620A
-6216
-621F
-6258
-6309
-633A
-633D
-6367
-6372
-6377
-637A
-63A0
-63AC
-63C3
-6451
-647A
-6492
-649E
-64AB
-64AD
-64B0
-64E2
-6566
-6590
-65A1
-65A7
-65AF
-65BC
-65ED
-6602
-660A
-660C
-660F
-6634
-6643
-6644
-664B
-664F
-6652
-665F
-6666
-6668
-667A
-6689
-66A2
-66D9
-66DD
-66F3
-670B
-6714
-674E
-674F
-6756
-675C
-676D
-6775
-6777
-6787
-67CA
-67CF
-67D1
-67D8
-67DA
-67F4
-67FE
-6816
-6817
-681E
-6842
-6850
-6854
-6867
-6876
-6881
-6893
-689B
-68A2
-68A7
-68AF
-68B6
-68F2
-6900
-690B
-691B
-6930
-693F
-694A
-6953
-6955
-695A
-6960
-6962
-696F
-698A
-698E
-699B
-69C7
-69CC
-69CD
-69D9
-69FB
-6A0B
-6A1F
-6A2B
-6A3A
-6A3D
-6A58
-6A59
-6A80
-6A8E
-6A9C
-6AC2
-6AD3
-6ADB
-6B23
-6B3D
-6B4E
-6B64
-6B86
-6BC5
-6BD8
-6BEC
-6C40
-6C50
-6C5D
-6C72
-6C8C
-6C93
-6CAB
-6D1B
-6D32
-6D35
-6D38
-6D69
-6D6C
-6DC0
-6DCB
-6DF3
-6DF5
-6E1A
-6E25
-6E4A
-6E58
-6E5B
-6E9C
-6EA2
-6EC9
-6F15
-6F23
-6F31
-6FAA
-6FE1
-7015
-7058
-7078
-707C
-70CF
-711A
-7130
-7149
-714C
-7164
-7199
-71CE
-71D5
-71E6
-71ED
-71FF
-723E
-7252
-725F
-7261
-727D
-7280
-72FC
-732A
-7345
-7396
-73B2
-73C0
-73C2
-73C8
-73CA
-7409
-7422
-7425
-7433
-7435
-7436
-745A
-745B
-745E
-7473
-7476
-74DC
-74E2
-7525
-752B
-7560
-7562
-758B
-758F
-7690
-7693
-7738
-77A5
-77E9
-7825\t7827
-786F
-7893
-7897
-78A7
-78A9
-78D0
-78EF
-7941
-7947
-7950
-7962
-7977
-797F
-7984
-798E
-79B0
-79B1
-79BD
-79BE
-79E4
-79E6
-7A00
-7A14
-7A1C
-7A1F
-7A63
-7A70
-7A79
-7A7F
-7A84
-7AAA
-7ABA
-7AE3
-7AEA
-7AFA
-7AFF
-7B08
-7B19
-7B20
-7B39
-7B48
-7B51
-7B94
-7B95
-7BC7
-7BE0
-7C1E
-7C3E
-7C7E
-7C9F
-7CA5
-7CCA
-7D10
-7D17
-7D18
-7D2C
-7D43
-7D46
-7D62
-7D9C
-7DB4
-7DB8
-7DBA
-7DBE
-7DCB
-7E1E
-7E61
-7E6B
-7E82
-7E8F
-7F9A
-7FD4
-7FE0
-8000
-800C
-8036
-803D
-8061
-8087
-808B
-80B4
-80E1
-80E4
-8129
-8139
-8154
-818F
-81E5
-821C
-8235
-8299
-82A5
-82A6
-82AD
-82B9
-82D1
-82D4
-82FA
-8304
-8305
-8309
-831C
-8338
-837B
-8389
-839E
-83AB
-83C5
-83D6
-83E9
-83EB
-83F1
-8404
-840A
-840C
-8420
-8429
-8431
-8461
-8463
-8466
-8475
-847A
-8490
-8494
-8499
-84B2
-84BC
-84C9
-84D1
-84EC
-84EE
-8513
-8523
-8526
-852D
-8543
-8549
-854E
-8557
-8568
-856A
-857E
-8599
-85A9
-85C1
-8607
-862D
-8766
-8776
-87BA
-87EC
-87F9
-881F
-887F
-8888
-88B4
-88DF
-88E1
-88F3
-8956
-8A0A
-8A23
-8A3B
-8A62
-8A6B
-8ABC
-8AC4
-8ACF
-8AD2
-8AFA
-8B02
-8B83
-8C79
-8CB0
-8CD1
-8D73
-8DE8
-8E44
-8E5F
-8F14
-8F2F
-8F3F
-8F5F
-8FB0
-8FBB
-8FBF
-8FC2
-8FC4
-8FE6
-8FEA
-9017
-9019
-901E
-9022
-9041
-9059
-9065
-907C
-9091
-90C1
-912D
-9149
-9187
-918D
-9190
-91AC
-91C9
-91D8
-91E7
-9291
-92D2
-92F8
-9306
-9310
-9318
-932B
-936C
-93A7
-9583
-958F
-95A4
-963F
-9640
-9688
-96BC
-96C0
-96C1
-96DB
-96EB
-971E
-9756
-9784
-978D
-9798
-97A0
-97AD
-9801
-980C
-9817
-985A
-98AF
-9957
-99A8
-99B3
-99B4
-99D5
-99FF
-9A4D
-9B41
-9B6F
-9B8E
-9BC9
-9BDB
-9C2F
-9C52
-9C57
-9CE9
-9CF3
-9CF6
-9D28
-9D3B
-9D5C
-9D6C
-9DD7
-9DF2
-9DF9
-9DFA
-9E92
-9E9F
-9EBF
-9ECE
-9EDB
-9F0E
-FA16
-FA46
-FA4A
-FA4F
-FA53
-4E58
-4E9E
-4F5B
-4F86
-50B3
-50DE
-50F9
-5109
-5152
-51A8
-51C9
-5269
-528D
-52F3
-5377
-537D
-55AE
-56B4
-5708
-570B
-5713
-5718
-57DC
-589E
-58D8
-58DE
-58EF
-58FD
-5967
-596C
-5B43
-5BE2
-5BE6
-5BEC
-5C07
-5C08
-5CEF
-5CFD
-5D8B
-5DE2
-5E36
-5EE3
-5EF3
-5F48
-5F4C
-5F9E
-5FB5
-5FB7
-6046
-60E0
-60E1
-613C
-61C9
-61F7
-6230
-6232
-62C2
-62D4
-62DC
-63ED
-6416
-641C
-64CA
-651D
-6536
-654D
-665A
-665D
-66C6
-66C9
-66FE
-689D
-69AE
-6A02
-6A23
-6A6B
-6AA2
-6AFB
-6B65
-6B77
-6BCF
-6C23
-6D89
-6DDA
-6DE8
-6E34
-6EAB
-6EEF
-6F81
-6FD5
-7027
-7028
-71C8
-71D2
-722D
-7232
-72C0
-72F9
-7378
-758A
-7626
-76C3
-76DC
-76E1
-771E
-788E
-7955
-79AA
-79AE
-7A3B
-7A57
-7CB9
-7DA0
-7DD6
-7DE3
-7E23
-7E31
-7E96
-807D
-81DF
-8207
-838A
-842C
-8597
-85B0
-85CF
-85DD
-85E5
-865B
-885E
-88DD
-89BD
-8B20
-8B93
-8CE3
-8CF4
-8F49
-90DE
-9189
-91C0
-9304
-934A
-93AD
-9444
-9677
-96AA
-96DC
-975C
-986F
-98DC
-99C8
-9A37
-9A57
-9AEE
-9DC4
-9EC3
-9ED1
-9ED8
-9F4A
-9F8D
-F91D
-F928
-F929
-F936
-F9D0
-FA19\tFA1B
-FA22
-FA26
-FA30
-FA31
-FA33\tFA35
-FA37
-FA38
-FA3A
-FA3B
-FA3D
-FA3F\tFA41
-FA43\tFA45
-FA47
-FA48
-FA4B\tFA4E
-FA50\tFA52
-FA54\tFA57
-FA59\tFA5C
-FA5F
-FA61\tFA65
-FA67\tFA69
-END
-}
-
 1;
 
 __END__
@@ -2846,83 +2002,30 @@ __END__
 
 =head1 NAME
 
-Lingua::JA::KanjiTable - User-Defined Character Properties for &#x5E38;&#x7528;&#x6F22;&#x5B57;&#x8868; and &#x4EBA;&#x540D;&#x7528;&#x6F22;&#x5B57;&#x8868;
+Lingua::JA::KanjiTable - Kanji properties
 
 =head1 SYNOPSIS
 
   use Lingua::JA::KanjiTable;
   use utf8;
 
-  '亜'   =~ /^\p{InJoyoKanji}$/   ? 1 : 0; # => 1
-  '亞'   =~ /^\p{InJoyoKanji}$/   ? 1 : 0; # => 0
-  '匁'   =~ /^\p{InJoyoKanji}$/   ? 1 : 0; # => 0
-  '叱'   =~ /^\p{InJouyouKanji}$/ ? 1 : 0; # => 0
-  '𠮟'   =~ /^\p{InJouyouKanji}$/ ? 1 : 0; # => 1
-  '恍惚' =~ /^\p{InJoyoKanji}+$/  ? 1 : 0; # => 0
-  '固唾' =~ /^\p{Lingua::JA::KanjiTable::InJoyoKanji20101130}+$/ ? 1 : 0; # => 1
-
-  '亞' =~ /^\p{InJinmeiyoKanji}$/ ? 1 : 0; # => 1
-  '匁' =~ /^\p{InJinmeiyoKanji}$/ ? 1 : 0; # => 1
-  '柊' =~ /^\p{InJinmeiyoKanji}$/ ? 1 : 0; # => 1
-  '苺' =~ /^\p{InJinmeiyoKanji}$/ ? 1 : 0; # => 1
-  '姦' =~ /^\p{InJinmeiyoKanji}$/ ? 1 : 0; # => 0
-
-=for test_synopsis_expectation_no_test
-
-  #Jinmei(名) check:
-  '太郎喜左衛門将時能' =~ /^\p{InJinmei}+$/ ? 1 : 0; # => 1
-  '愛子エンジェル'     =~ /^\p{InJinmei}+$/ ? 1 : 0; # => 1
-  'み〜こ'             =~ /^\p{InJinmei}+$/ ? 1 : 0; # => 0
-  'ニャー'             =~ /^\p{InJinmei}+$/ ? 1 : 0; # => 1
-  '奈々'               =~ /^\p{InJinmei}+$/ ? 1 : 0; # => 1
-  '〆子'               =~ /^\p{InJinmei}+$/ ? 1 : 0; # => 0
-
-  sub InJinmei
-  {
-      return <<"END";
-  +Lingua::JA::KanjiTable::InJoyoKanji
-  +Lingua::JA::KanjiTable::InJinmeiyoKanji
-  3005
-  3041\t3096
-  309D
-  309E
-  30A1\t30FA
-  30FC\t30FE
-  END
-  }
+  '亜' =~ /^\p{InJoyoKanji}$/   ? 1 : 0; # => 1
+  '亞' =~ /^\p{InJoyoKanji}$/   ? 1 : 0; # => 0
+  '叱' =~ /^\p{InJouyouKanji}$/ ? 1 : 0; # => 0
+  '𠮟' =~ /^\p{InJouyouKanji}$/ ? 1 : 0; # => 1
 
 =head1 DESCRIPTION
 
-Lingua::JA::KanjiTable provides user-defined character properties for 常用漢字表 and 人名用漢字表.
+Lingua::JA::KanjiTable provides user-defined Unicode properties relating to Kanji.
 
 =head1 EXPORTS
 
-By default Lingua::JA::KanjiTable exports the following user-defined character properties:
-
 =over 4
 
-=item InJoyoKanji - The latest Jouyou Kanji table（平成22年11月30日内閣告示第2号）
+=item InJoyoKanji - 常用漢字表（平成22年11月30日内閣告示）
 
 =item InJouyouKanji - ditto
 
-=item InJinmeiyoKanji - The latest Jinmeiyou Kanji table（2010年11月30日版）
-
-=item InJinmeiyouKanji - ditto
-
-=back
-
-The following properties are not exported by default:
-
-=over 4
-
-=item InJoyoKanji20101130 - 常用漢字表（平成22年11月30日内閣告示第2号）
-
-=item InJouyouKanji20101130 - ditto
-
-=item InJinmeiyoKanji20101130 - 人名用漢字表（2010年11月30日版）
-
-=item InJinmeiyouKanji20101130 - ditto
-
 =back
 
 =head1 SEE ALSO
@@ -2931,14 +2034,6 @@ L<Jōyō kanji - Wikipedia, the free encyclopedia|http://en.wikipedia.org/wiki/J
 
 L<常用漢字表（平成22年11月30日内閣告示）|http://www.bunka.go.jp/kokugo_nihongo/pdf/jouyoukanjihyou_h22.pdf>
 
-L<Jinmeiyō kanji - Wikipedia, the free encyclopedia|http://en.wikipedia.org/wiki/Jinmeiy%C5%8D_kanji>
-
-L<人名用漢字表|http://www.moj.go.jp/content/000058122.pdf>
-
-戸籍法 第50条
-
-戸籍法施行規則 第60条
-
 =head1 LICENSE
 
 Copyright (C) pawa.
